@@ -45,8 +45,8 @@ const getMenuVisibility = () => {
     agent: process.env.NEXT_PUBLIC_ENABLE_AGENT === 'true',
     assistant: process.env.NEXT_PUBLIC_ENABLE_ASSISTANT === 'true',
     document: process.env.NEXT_PUBLIC_ENABLE_DOCUMENT === 'true',
-    flowai: process.env.NEXT_PUBLIC_ENABLE_FLOWAI !== 'false', // 기본값은 true
-    business: process.env.NEXT_PUBLIC_ENABLE_BUSINESS !== 'false', // 기본값은 true
+    flowai: process.env.NEXT_PUBLIC_ENABLE_FLOWAI === 'true',
+    business: process.env.NEXT_PUBLIC_ENABLE_BUSINESS === 'true',
     support: process.env.NEXT_PUBLIC_ENABLE_SUPPORT === 'true',
     ragAdmin: process.env.NEXT_PUBLIC_ENABLE_RAG_ADMIN === 'true',
     modelAdmin: process.env.NEXT_PUBLIC_ENABLE_MODEL_ADMIN === 'true',
